@@ -10,6 +10,6 @@ __DATA__
 
 option default \
     -Munder \
-    --under-custom-colormap \
-    --under-line \
+    --use-custom-colormap \
+    --place-line \
     --re '\A' --all
